@@ -1,10 +1,4 @@
-
-#ifndef ___clock_marshal_MARSHAL_H__
-#define ___clock_marshal_MARSHAL_H__
-
-#include	<glib-object.h>
-
-G_BEGIN_DECLS
+#include <glib-object.h>
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -52,27 +46,30 @@ G_BEGIN_DECLS
 #define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
-
 /* POINTER:VOID (clock-marshallers.list:1) */
-G_GNUC_INTERNAL void _clock_marshal_POINTER__VOID (GClosure     *closure,
-                                                   GValue       *return_value,
-                                                   guint         n_param_values,
-                                                   const GValue *param_values,
-                                                   gpointer      invocation_hint,
-                                                   gpointer      marshal_data);
+/* Prototype for -Wmissing-prototypes */
+G_BEGIN_DECLS
+G_GNUC_INTERNAL
+void _clock_marshal_POINTER__VOID (GClosure     *closure,
+                                   GValue       *return_value,
+                                   guint         n_param_values,
+                                   const GValue *param_values,
+                                   gpointer      invocation_hint,
+                                   gpointer      marshal_data);
+G_END_DECLS
 void
 _clock_marshal_POINTER__VOID (GClosure     *closure,
-                              GValue       *return_value G_GNUC_UNUSED,
+                              GValue       *return_value,
                               guint         n_param_values,
                               const GValue *param_values,
                               gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
-  typedef gpointer (*GMarshalFunc_POINTER__VOID) (gpointer     data1,
-                                                  gpointer     data2);
-  GMarshalFunc_POINTER__VOID callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef gpointer (*GMarshalFunc_POINTER__VOID) (gpointer data1,
+                                                  gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_POINTER__VOID callback;
   gpointer v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -97,12 +94,16 @@ _clock_marshal_POINTER__VOID (GClosure     *closure,
 }
 
 /* VOID:OBJECT,STRING (clock-marshallers.list:2) */
-G_GNUC_INTERNAL void _clock_marshal_VOID__OBJECT_STRING (GClosure     *closure,
-                                                         GValue       *return_value,
-                                                         guint         n_param_values,
-                                                         const GValue *param_values,
-                                                         gpointer      invocation_hint,
-                                                         gpointer      marshal_data);
+/* Prototype for -Wmissing-prototypes */
+G_BEGIN_DECLS
+G_GNUC_INTERNAL
+void _clock_marshal_VOID__OBJECT_STRING (GClosure     *closure,
+                                         GValue       *return_value,
+                                         guint         n_param_values,
+                                         const GValue *param_values,
+                                         gpointer      invocation_hint,
+                                         gpointer      marshal_data);
+G_END_DECLS
 void
 _clock_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                     GValue       *return_value G_GNUC_UNUSED,
@@ -111,13 +112,13 @@ _clock_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                     gpointer      invocation_hint G_GNUC_UNUSED,
                                     gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__OBJECT_STRING) (gpointer     data1,
-                                                    gpointer     arg_1,
-                                                    gpointer     arg_2,
-                                                    gpointer     data2);
-  GMarshalFunc_VOID__OBJECT_STRING callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__OBJECT_STRING) (gpointer data1,
+                                                    gpointer arg1,
+                                                    gpointer arg2,
+                                                    gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_STRING callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -140,25 +141,29 @@ _clock_marshal_VOID__OBJECT_STRING (GClosure     *closure,
 }
 
 /* INT:VOID (clock-marshallers.list:3) */
-G_GNUC_INTERNAL void _clock_marshal_INT__VOID (GClosure     *closure,
-                                               GValue       *return_value,
-                                               guint         n_param_values,
-                                               const GValue *param_values,
-                                               gpointer      invocation_hint,
-                                               gpointer      marshal_data);
+/* Prototype for -Wmissing-prototypes */
+G_BEGIN_DECLS
+G_GNUC_INTERNAL
+void _clock_marshal_INT__VOID (GClosure     *closure,
+                               GValue       *return_value,
+                               guint         n_param_values,
+                               const GValue *param_values,
+                               gpointer      invocation_hint,
+                               gpointer      marshal_data);
+G_END_DECLS
 void
 _clock_marshal_INT__VOID (GClosure     *closure,
-                          GValue       *return_value G_GNUC_UNUSED,
+                          GValue       *return_value,
                           guint         n_param_values,
                           const GValue *param_values,
                           gpointer      invocation_hint G_GNUC_UNUSED,
                           gpointer      marshal_data)
 {
-  typedef gint (*GMarshalFunc_INT__VOID) (gpointer     data1,
-                                          gpointer     data2);
-  GMarshalFunc_INT__VOID callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef gint (*GMarshalFunc_INT__VOID) (gpointer data1,
+                                          gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_INT__VOID callback;
   gint v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -182,7 +187,3 @@ _clock_marshal_INT__VOID (GClosure     *closure,
   g_value_set_int (return_value, v_return);
 }
 
-G_END_DECLS
-
-#endif /* ___clock_marshal_MARSHAL_H__ */
-
